@@ -20,4 +20,4 @@ class RelatedArticleResponse:
 @dataclass(frozen=True)
 class RelatedArticlesResponse:
     related_articles: list[RelatedArticleResponse]
-    total_count: int
+    next_cursor: str | None
