@@ -1,10 +1,12 @@
 from google.cloud import ndb
 
+from news_toolkit_api.background_tasks.utils import async_timeout
 from news_toolkit_api.config.settings import NEWS_TOOLKIT_MAX_RECURSION_DEPTH
 from news_toolkit_api.db.article import Article
 from news_toolkit_api.repository.article import ArticleRepository
 
 
+@async_timeout()
 async def background_task_article(
     client: ndb.Client,
     article_repository: ArticleRepository,
