@@ -1,10 +1,12 @@
 from google.cloud import ndb
 
 from news_toolkit_api.background_tasks.article import background_task_article
+from news_toolkit_api.background_tasks.utils import async_timeout
 from news_toolkit_api.db import Feed
 from news_toolkit_api.repository import ArticleRepository, FeedRepository
 
 
+@async_timeout()
 async def background_task_feed(
     client: ndb.Client,
     article_repository: ArticleRepository,
