@@ -1,6 +1,6 @@
 from google.cloud import ndb
 
-from news_toolkit_api.utils import sha3_256_hash
+from news_toolkit_api.utils import sha3_hash
 
 
 class RelatedArticle(ndb.Model):
@@ -8,6 +8,7 @@ class RelatedArticle(ndb.Model):
     title = ndb.StringProperty(required=True)
     category = ndb.StringProperty(required=True)
     image_url = ndb.StringProperty(required=True)
+    description = ndb.StringProperty()
     author = ndb.StringProperty()
     published_at = ndb.DateTimeProperty()
 
@@ -30,4 +31,4 @@ class Article(ndb.Model):
 
     @property
     def id(self) -> str:
-        return sha3_256_hash(f"{self.article_id}&{self.cursor}")
+        return sha3_hash(f"{self.article_id}&{self.cursor}")
