@@ -1,6 +1,6 @@
 from google.cloud import ndb
 
-from news_toolkit_api.utils import sha3_256_hash
+from news_toolkit_api.utils import sha3_hash
 
 
 class FeedArticle(ndb.Model):
@@ -10,8 +10,7 @@ class FeedArticle(ndb.Model):
     image_url = ndb.StringProperty(required=True)
     subtitle = ndb.StringProperty()
     author = ndb.StringProperty()
-    published_at = ndb.DateTimeProperty(required=True)
-    created_at = ndb.DateTimeProperty(required=True)
+    published_at = ndb.DateTimeProperty()
 
 
 class Feed(ndb.Model):
@@ -23,4 +22,4 @@ class Feed(ndb.Model):
 
     @property
     def id(self) -> str:
-        return sha3_256_hash(f"{self.category}&{self.cursor}")
+        return sha3_hash(f"{self.category}&{self.cursor}")
