@@ -3,7 +3,7 @@ import argparse
 from google.cloud import ndb
 
 from news_toolkit_api.db import Category
-from news_toolkit_api.utils import sha3_256_hash
+from news_toolkit_api.utils import sha3_hash
 
 client = ndb.Client()
 
@@ -15,9 +15,10 @@ if __name__ == "__main__":
     with client.context():
         categories = [
             Category(
-                key=ndb.Key(Category, sha3_256_hash(category)),
+                key=ndb.Key(Category, sha3_hash(category)),
                 name=category,
+                order=i,
             )
-            for category in args.categories
+            for i, category in enumerate(args.categories)
         ]
         ndb.put_multi(categories)
