@@ -4,7 +4,7 @@ from datetime import datetime, timedelta
 from news_toolkit_api.config.settings import NEWS_TOOLKIT_UPDATE_INTERVAL_MINUTES
 
 
-def sha3_256_hash(data: str) -> str:
+def sha3_hash(data: str) -> str:
     """
     Computes the SHA-3 256-bit hash of the given string.
 
